@@ -1,6 +1,8 @@
-from .conversable_agent import ConversableAgent
 from typing import Callable, Dict, Literal, Optional, Union
 
+from .conversable_agent import ConversableAgent
+from autogen.runtime_logging import logging_enabled, log_new_agent
+
 
 class AssistantAgent(ConversableAgent):
     """(In preview) Assistant agent, designed to solve a task with LLM.
@@ -26,6 +28,8 @@ When you find an answer, verify the answer carefully. Include verifiable evidenc
 Reply "TERMINATE" in the end when everything is done.
     """
 
+    DEFAULT_DESCRIPTION = "A helpful and general-purpose AI assistant that has strong language skills, Python skills, and Linux command line skills."
+
     def __init__(
         self,
         name: str,
@@ -34,7 +38,7 @@ Reply "TERMINATE" in the end when everything is done.
         is_termination_msg: Optional[Callable[[Dict], bool]] = None,
         max_consecutive_auto_reply: Optional[int] = None,
         human_input_mode: Optional[str] = "NEVER",
-        code_execution_config: Optional[Union[Dict, Literal[False]]] = False,
+        description: Optional[str] = None,
         **kwargs,
     ):
         """
@@ -42,7 +46,7 @@ Reply "TERMINATE" in the end when everything is done.
             name (str): agent name.
             system_message (str): system message for the ChatCompletion inference.
                 Please override this attribute if you want to reprogram the agent.
-            llm_config (dict): llm inference configuration.
+            llm_config (dict or False or None): llm inference configuration.
                 Please refer to [OpenAIWrapper.create](/docs/reference/oai/client#create)
                 for available options.
             is_termination_msg (function): a function that takes a message in the form of a dictionary
@@ -60,7 +64,15 @@ Reply "TERMINATE" in the end when everything is done.
             is_termination_msg,
             max_consecutive_auto_reply,
             human_input_mode,
-            code_execution_config=code_execution_config,
             llm_config=llm_config,
+            description=description,
             **kwargs,
         )
+        if logging_enabled():
+            log_new_agent(self, locals())
+
+        # Update the provided description if None, and we are using the default system_message,
+        # then use the default description.
+        if description is None:
+            if system_message == self.DEFAULT_SYSTEM_MESSAGE:
+                self.description = self.DEFAULT_DESCRIPTION
