@@ -3,6 +3,7 @@ import openai
 import json
 import time
 import logging
+import copy
 
 from autogen import OpenAIWrapper
 from autogen.oai.openai_utils import retrieve_assistants_by_name
@@ -26,6 +27,8 @@ class GPTAssistantAgent(ConversableAgent):
         instructions: Optional[str] = None,
         llm_config: Optional[Union[Dict, bool]] = None,
         overwrite_instructions: bool = False,
+        overwrite_tools: bool = False,
+        **kwargs,
     ):
         """
         Args:
@@ -44,20 +47,50 @@ class GPTAssistantAgent(ConversableAgent):
                 - tools: Give Assistants access to OpenAI-hosted tools like Code Interpreter and Knowledge Retrieval,
                         or build your own tools using Function calling. ref https://platform.openai.com/docs/assistants/tools
                 - file_ids: files used by retrieval in run
-            overwrite_instructions (bool): whether to overwrite the instructions of an existing assistant.
+            overwrite_instructions (bool): whether to overwrite the instructions of an existing assistant. This parameter is in effect only when assistant_id is specified in llm_config.
+            overwrite_tools (bool): whether to overwrite the tools of an existing assistant. This parameter is in effect only when assistant_id is specified in llm_config.
+            kwargs (dict): Additional configuration options for the agent.
+                - verbose (bool): If set to True, enables more detailed output from the assistant thread.
+                - Other kwargs: Except verbose, others are passed directly to ConversableAgent.
         """
+
+        self._verbose = kwargs.pop("verbose", False)
+        super().__init__(
+            name=name, system_message=instructions, human_input_mode="NEVER", llm_config=llm_config, **kwargs
+        )
+
+        if llm_config is False:
+            raise ValueError("llm_config=False is not supported for GPTAssistantAgent.")
+
         # Use AutoGen OpenAIWrapper to create a client
-        oai_wrapper = OpenAIWrapper(**llm_config)
+        model_name = "gpt-4-0125-preview"
+        openai_client_cfg = copy.deepcopy(llm_config)
+        # GPTAssistantAgent's azure_deployment param may cause NotFoundError (404) in client.beta.assistants.list()
+        # See: https://github.com/microsoft/autogen/pull/1721
+        if openai_client_cfg.get("config_list") is not None and len(openai_client_cfg["config_list"]) > 0:
+            model_name = openai_client_cfg["config_list"][0].pop("model", "gpt-4-0125-preview")
+        else:
+            model_name = openai_client_cfg.pop("model", "gpt-4-0125-preview")
+
+        logger.warning("OpenAI client config of GPTAssistantAgent(%s) - model: %s", name, model_name)
+
+        oai_wrapper = OpenAIWrapper(**openai_client_cfg)
         if len(oai_wrapper._clients) > 1:
             logger.warning("GPT Assistant only supports one OpenAI client. Using the first client in the list.")
-        self._openai_client = oai_wrapper._clients[0]
+
+        self._openai_client = oai_wrapper._clients[0]._oai_client
         openai_assistant_id = llm_config.get("assistant_id", None)
         if openai_assistant_id is None:
             # try to find assistant by name first
             candidate_assistants = retrieve_assistants_by_name(self._openai_client, name)
+            if len(candidate_assistants) > 0:
+                # Filter out candidates with the same name but different instructions, file IDs, and function names.
+                candidate_assistants = self.find_matching_assistant(
+                    candidate_assistants, instructions, llm_config.get("tools", []), llm_config.get("file_ids", [])
+                )
 
             if len(candidate_assistants) == 0:
-                logger.warning(f"assistant {name} does not exist, creating a new assistant")
+                logger.warning("No matching assistant found, creating a new assistant")
                 # create a new assistant
                 if instructions is None:
                     logger.warning(
@@ -68,15 +101,14 @@ class GPTAssistantAgent(ConversableAgent):
                     name=name,
                     instructions=instructions,
                     tools=llm_config.get("tools", []),
-                    model=llm_config.get("model", "gpt-4-1106-preview"),
+                    model=model_name,
                     file_ids=llm_config.get("file_ids", []),
                 )
             else:
-                if len(candidate_assistants) > 1:
-                    logger.warning(
-                        f"Multiple assistants with name {name} found. Using the first assistant in the list. "
-                        f"Please specify the assistant ID in llm_config to use a specific assistant."
-                    )
+                logger.warning(
+                    "Matching assistant found, using the first matching assistant: %s",
+                    candidate_assistants[0].__dict__,
+                )
                 self._openai_assistant = candidate_assistants[0]
         else:
             # retrieve an existing assistant
@@ -100,17 +132,38 @@ class GPTAssistantAgent(ConversableAgent):
                     "overwrite_instructions is False. Provided instructions will be used without permanently modifying the assistant in the API."
                 )
 
-        super().__init__(
-            name=name,
-            system_message=instructions,
-            human_input_mode="NEVER",
-            llm_config=llm_config,
-        )
+            # Check if tools are specified in llm_config
+            specified_tools = llm_config.get("tools", None)
+
+            if specified_tools is None:
+                # Check if the current assistant has tools defined
+                if self._openai_assistant.tools:
+                    logger.warning(
+                        "No tools were provided for given assistant. Using existing tools from assistant API."
+                    )
+                else:
+                    logger.info(
+                        "No tools were provided for the assistant, and the assistant currently has no tools set."
+                    )
+            elif overwrite_tools is True:
+                # Tools are specified and overwrite_tools is True; update the assistant's tools
+                logger.warning(
+                    "overwrite_tools is True. Provided tools will be used and will modify the assistant in the API"
+                )
+                self._openai_assistant = self._openai_client.beta.assistants.update(
+                    assistant_id=openai_assistant_id,
+                    tools=llm_config.get("tools", []),
+                )
+            else:
+                # Tools are specified but overwrite_tools is False; do not update the assistant's tools
+                logger.warning("overwrite_tools is False. Using existing tools from assistant API.")
 
         # lazily create threads
         self._openai_threads = {}
         self._unread_index = defaultdict(int)
         self.register_reply(Agent, GPTAssistantAgent._invoke_assistant)
+        self.register_reply(Agent, GPTAssistantAgent.check_termination_and_human_reply)
+        self.register_reply(Agent, GPTAssistantAgent.a_check_termination_and_human_reply)
 
     def _invoke_assistant(
         self,
@@ -201,7 +254,7 @@ class GPTAssistantAgent(ConversableAgent):
                                 new_messages.append(
                                     {
                                         "role": msg.role,
-                                        "content": f"Recieved file id={content.image_file.file_id}",
+                                        "content": f"Received file id={content.image_file.file_id}",
                                     }
                                 )
                 return new_messages
@@ -209,7 +262,7 @@ class GPTAssistantAgent(ConversableAgent):
                 actions = []
                 for tool_call in run.required_action.submit_tool_outputs.tool_calls:
                     function = tool_call.function
-                    is_exec_success, tool_response = self.execute_function(function.dict())
+                    is_exec_success, tool_response = self.execute_function(function.dict(), self._verbose)
                     tool_response["metadata"] = {
                         "tool_call_id": tool_call.id,
                         "run_id": run.id,
@@ -217,7 +270,7 @@ class GPTAssistantAgent(ConversableAgent):
                     }
 
                     logger.info(
-                        "Intermediate executing(%s, Sucess: %s) : %s",
+                        "Intermediate executing(%s, Success: %s) : %s",
                         tool_response["name"],
                         is_exec_success,
                         tool_response["content"],
@@ -366,3 +419,53 @@ class GPTAssistantAgent(ConversableAgent):
         """Delete the assistant from OAI assistant API"""
         logger.warning("Permanently deleting assistant...")
         self._openai_client.beta.assistants.delete(self.assistant_id)
+
+    def find_matching_assistant(self, candidate_assistants, instructions, tools, file_ids):
+        """
+        Find the matching assistant from a list of candidate assistants.
+        Filter out candidates with the same name but different instructions, file IDs, and function names.
+        TODO: implement accurate match based on assistant metadata fields.
+        """
+        matching_assistants = []
+
+        # Preprocess the required tools for faster comparison
+        required_tool_types = set(tool.get("type") for tool in tools)
+        required_function_names = set(
+            tool.get("function", {}).get("name")
+            for tool in tools
+            if tool.get("type") not in ["code_interpreter", "retrieval"]
+        )
+        required_file_ids = set(file_ids)  # Convert file_ids to a set for unordered comparison
+
+        for assistant in candidate_assistants:
+            # Check if instructions are similar
+            if instructions and instructions != getattr(assistant, "instructions", None):
+                logger.warning(
+                    "instructions not match, skip assistant(%s): %s",
+                    assistant.id,
+                    getattr(assistant, "instructions", None),
+                )
+                continue
+
+            # Preprocess the assistant's tools
+            assistant_tool_types = set(tool.type for tool in assistant.tools)
+            assistant_function_names = set(tool.function.name for tool in assistant.tools if hasattr(tool, "function"))
+            assistant_file_ids = set(getattr(assistant, "file_ids", []))  # Convert to set for comparison
+
+            # Check if the tool types, function names, and file IDs match
+            if required_tool_types != assistant_tool_types or required_function_names != assistant_function_names:
+                logger.warning(
+                    "tools not match, skip assistant(%s): tools %s, functions %s",
+                    assistant.id,
+                    assistant_tool_types,
+                    assistant_function_names,
+                )
+                continue
+            if required_file_ids != assistant_file_ids:
+                logger.warning("file_ids not match, skip assistant(%s): %s", assistant.id, assistant_file_ids)
+                continue
+
+            # Append assistant to matching list if all conditions are met
+            matching_assistants.append(assistant)
+
+        return matching_assistants
